# Arcaea Offline

English | [简体中文](./README.zh_Hans.md)

<span>
  <img src="./assets/banner.png" style="height: 175px; object-fit: contain;">
</span>

> Accept <i><b>lr</b><sub>lowiro</sub></i>

## WIP

> **Warning**
> This project is under active development, thus it is unstable and API may change frequently.

## What is this？

This is the core library of `Arcaea Offline`, designed to manage player scores, calculate their potential, and provide various useful tools.

## How to use this？

This repository is a python library.

For general users, if you don't know what is a "library", you may be interested about [this GUI](https://github.com/283375/arcaea-offline-pyside-ui).

For developers, the documentation is under construction. Check back later!

## License

This file is part of arcaea-offline.

arcaea-offline is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

arcaea-offline is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with arcaea-offline. If not, see <https://www.gnu.org/licenses/>.

## Credits

[Arcaea-Infinity/ArcaeaSongDatabase](https://github.com/Arcaea-Infinity/ArcaeaSongDatabase)
